@@ -9,7 +9,9 @@
 import os
 import fcntl
 import termios
+import struct
 import curses
+import readline
 
 from cli.terminal import Terminal
 
@@ -50,3 +52,8 @@ class PosixTerminal(Terminal):
 
     def close(self):
         os.close(self._tty)
+
+    def readline(self, prompt):
+        line = raw_input(prompt)
+        line += '\n'
+        return line
